@@ -44,7 +44,7 @@ class KnowledgeBase:
         for document in resp['body']:
             kb_document = KnowledgeBaseDocument(
                 kb_id=document['id'],
-                content=document['content'],
+                content=None,
                 title=document['title'],
                 link_to_source=document['link_to_source'],
                 supp_id=document['supp_id'],
@@ -78,7 +78,7 @@ class KnowledgeBaseDocument:
     """
     The KnowledgeBaseDocument class is used to create and delete documents in a knowledge base.
     """
-    def __init__(self, kb_id: str, content: str, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None, doc_id: str = None):
+    def __init__(self, kb_id: str, content: str = None, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None, doc_id: str = None):
         self.kb_id = kb_id
         self.content = content # content is a string
         self.title = title
@@ -88,7 +88,7 @@ class KnowledgeBaseDocument:
         self.doc_id = doc_id
 
     def create(self):
-        url = BASE_URL + f'knowledge_bases/{self.kb_id}/documents'
+        url = BASE_URL + f'knowledge_bases/{self.kb_id}/documents/raw_text'
         payload = {
             'content': self.content
         }
@@ -172,7 +172,7 @@ def list_documents_in_kb(kb_title: str, verbose=True):
     if verbose:
         print ("\nDocuments:")
         for document_obj in documents.values():
-            print (f"title: {document_obj.title}\ncontent: {document_obj.content[:100]}\n\n")
+            print (f"title: {document_obj.title}\n\n")
     return documents
 
 def read_file(file_path: str):
