@@ -13,6 +13,15 @@ def init(api_key_id: str, api_key_secret: str, verbose: bool = False):
     os.environ['SUPERPOWERED_API_KEY'] = token
 
 def get_headers():
+    if 'SUPERPOWERED_API_KEY' not in os.environ:
+        # initialize API key
+        try:
+            api_key_id = os.getenv("SUPERPOWERED_API_KEY_ID")
+            api_key_secret = os.getenv("SUPERPOWERED_API_KEY_SECRET")
+            init(api_key_id=api_key_id, api_key_secret=api_key_secret)
+        except:
+            raise NoApiKeyError()
+    
     token = os.environ['SUPERPOWERED_API_KEY']
     HEADERS = {'Authorization': f'Bearer {token}'}
     return HEADERS
@@ -20,7 +29,7 @@ def get_headers():
 # exceptions
 class NoApiKeyError(Exception):
     def __init__(self):
-        super().__init__('No API key has been set. Please run check that your API key is correct and then run `superpowered.init(api_key)` before continuing')
+        super().__init__('Could not find API key ID and secret. Please check that you have the following environment variables set: SUPERPOWERED_API_KEY_ID, SUPERPOWERED_API_KEY_SECRET.')
 
 def _format_http_response(resp: requests.Response):
     if resp.status_code != 200:
